bio-attention.embed Reference
===============

Here be modules that will help embed inputs in different ways

.. autoclass:: bio_attention.embed.DiscreteEmbedding
   :members:

.. autoclass:: bio_attention.embed.ContinuousEmbedding
   :members:

.. autoclass:: bio_attention.embed.BinaryEmbedding
   :members:

.. autoclass:: bio_attention.embed.BinEmbedding
   :members:

.. autoclass:: bio_attention.embed.CLS
   :members: